==> aws-android-sdk-kms-2.2.15-sources.jar: com/amazonaws/services/kms/model/transform/KeyListEntryJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kms.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.kms.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * Key List Entry JSON Unmarshaller
 */
public class KeyListEntryJsonUnmarshaller implements Unmarshaller<KeyListEntry, JsonUnmarshallerContext> {

    public KeyListEntry unmarshall(JsonUnmarshallerContext context) throws Exception {
        KeyListEntry keyListEntry = new KeyListEntry();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            
            if (name.equals("KeyId")) {
                keyListEntry.setKeyId(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            if (name.equals("KeyArn")) {
                keyListEntry.setKeyArn(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            {
                reader.skipValue();
            }
            
        }
        reader.endObject();
        
        return keyListEntry;
    }

    private static KeyListEntryJsonUnmarshaller instance;
    public static KeyListEntryJsonUnmarshaller getInstance() {
        if (instance == null) instance = new KeyListEntryJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-kms-2.3.0-sources.jar: com/amazonaws/services/kms/model/transform/KeyListEntryJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kms.model.transform;

import com.amazonaws.services.kms.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO KeyListEntry
 */
class KeyListEntryJsonUnmarshaller implements Unmarshaller<KeyListEntry, JsonUnmarshallerContext> {

    public KeyListEntry unmarshall(JsonUnmarshallerContext context) throws Exception {
        KeyListEntry keyListEntry = new KeyListEntry();
        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("KeyId")) {
                keyListEntry.setKeyId(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("KeyArn")) {
                keyListEntry.setKeyArn(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return keyListEntry;
    }

    private static KeyListEntryJsonUnmarshaller instance;

    public static KeyListEntryJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new KeyListEntryJsonUnmarshaller();
        return instance;
    }
}
